@@ -1,21 +1,19 @@
 import os
 import imghdr
-
-
-class ExtensionsConstants:
+    
+    
+class Extensions():
+    
     EXT_JPG = 'jpg'
     EXT_JPEG = 'jpeg'
     EXT_PNG = 'png'
     EXT_SVG = 'svg'
     
-    
-class Extensions:
-    
-    IMAGE_FILES_EXTENSIONS = (
-        ExtensionsConstants.EXT_JPEG,
-        ExtensionsConstants.EXT_JPG,
-        ExtensionsConstants.EXT_PNG,
-        ExtensionsConstants.EXT_SVG
+    GROUP_TYPE_IMAGE = (
+        Extensions.EXT_JPEG,
+        Extensions.EXT_JPG,
+        Extensions.EXT_PNG,
+        Extensions.EXT_SVG
     )
 
 
@@ -51,7 +49,7 @@ class File:
         if not self.exists():
             return False
         
-        return imghdr.what(self._path) in Extensions.IMAGE_FILES_EXTENSIONS
+        return imghdr.what(self._path) in Extensions.GROUP_TYPE_IMAGE
     
     @property
     def name(self):
